Learn R Programming

hclust1d (version 0.1.1)

hclust1d-package: hclust1d-package

Description

Univariate agglomerative hierarchical clustering with a comprehensive list of choices of a linkage function in O(n*log n) time. The better algorithmic time complexity is paired with an efficient 'C++' implementation.

Arguments

All <code>hclust1d</code> Functions

Similar in use to stats::hclust. It consists of the following functions:

hclust1d - univariate agglomerative hierarchical clustering routine.

supported_methods - lists all currently supported linkage methods.

supported_dist.methods - lists all currently supported distance methods.

For more information see a friendly "Getting started" vignette:

Examples

Run this code
if (FALSE) {
vignette("getting-started", package="hclust1d")
}

Run the code above in your browser using DataLab